==> haskell-juicypixels-3.2.9.4-3-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-juicypixels.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: JuicyPixels
version: 3.2.9.4
id: JuicyPixels-3.2.9.4-4bOxotiTJSs7FecxD6Ys04
key: JuicyPixels-3.2.9.4-4bOxotiTJSs7FecxD6Ys04
license: BSD3
maintainer: vincent.berthoux@gmail.com
stability: Stable
homepage: https://github.com/Twinside/Juicy.Pixels
synopsis: Picture loading/serialization (in png, jpeg, bitmap, gif, tga, tiff and radiance)
description:
    <<data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAAMAAAADABAMAAACg8nE0AAAAElBMVEUAAABJqDSTWEL/qyb///8AAABH/1GTAAAAAXRSTlMAQObYZgAAAN5JREFUeF7s1sEJgFAQxFBbsAV72v5bEVYWPwT/XDxmCsi7zvHXavYREBDI3XP2GgICqBBYuwIC+/rVayPUAyAg0HvIXBcQoDFDGnUBgWQQ2Bx3AYFaRoBpAQHWb3bt2ARgGAiCYFFuwf3X5HA/McgGJWI2FdykCv4aBYzmKwDwvl6NVmUAAK2vlwEALK7fo88GANB6HQsAAAAAAAAA7P94AQCzswEAAAAAAAAAAAAAAAAAAICzh4UAO4zWAYBfRutHA4Bn5C69JhowAMGoBaMWDG0wCkbBKBgFo2AUAACPmegUST/IJAAAAABJRU5ErkJggg==>>
    .
    This library can load and store images in PNG,Bitmap, Jpeg, Radiance, Tiff and Gif images.
category: Codec, Graphics, Image
author: Vincent Berthoux
exposed: True
indefinite: False
exposed-modules:
    Codec.Picture Codec.Picture.Bitmap Codec.Picture.ColorQuant
    Codec.Picture.Gif Codec.Picture.HDR Codec.Picture.Jpg
    Codec.Picture.Metadata Codec.Picture.Metadata.Exif
    Codec.Picture.Png Codec.Picture.Saving Codec.Picture.Tga
    Codec.Picture.Tiff Codec.Picture.Types
hidden-modules: Codec.Picture.Jpg.DefaultTable
                Codec.Picture.Jpg.Metadata Codec.Picture.Jpg.FastIdct
                Codec.Picture.Jpg.FastDct Codec.Picture.Jpg.Types
                Codec.Picture.Jpg.Common Codec.Picture.Jpg.Progressive
                Codec.Picture.Gif.LZW Codec.Picture.Gif.LZWEncoding
                Codec.Picture.Png.Export Codec.Picture.Png.Type
                Codec.Picture.Png.Metadata Codec.Picture.Tiff.Metadata
                Codec.Picture.Tiff.Types Codec.Picture.BitWriter
                Codec.Picture.InternalHelper Codec.Picture.VectorByteConversion
abi: 350a1b622d555461a647252cdf71cdd1
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/JuicyPixels-3.2.9.4
library-dirs: /usr/lib/ghc-8.2.2/site-local/JuicyPixels-3.2.9.4
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.2.2/JuicyPixels-3.2.9.4
hs-libraries: HSJuicyPixels-3.2.9.4-4bOxotiTJSs7FecxD6Ys04
include-dirs: /usr/lib/ghc-8.2.2/site-local/JuicyPixels-3.2.9.4/include
depends:
    base-4.10.1.0 bytestring-0.10.8.2 mtl-2.2.2-8XubxMJDT8QLsstvlNotkc
    binary-0.8.5.1 zlib-0.6.2-FRkEyCRDCMJ4V7FViKOnGY
    transformers-0.5.2.0 vector-0.12.0.1-JlawpRjIcMJIYPJVsWriIA
    primitive-0.6.3.0-CXy1O9sQYlI58rn9KQkFyo deepseq-1.4.3.0
    containers-0.5.10.2
abi-depends: base-4.10.1.0=0ea45191c57c268b2351cb731ab6a0d6
             bytestring-0.10.8.2=4b2726b654ceeff6535e698a2a1e724e
             mtl-2.2.2-8XubxMJDT8QLsstvlNotkc=9d788b97813db77c2d48570ade6e04a9
             binary-0.8.5.1=33c677d3ced9a5afbc7b354509494653
             zlib-0.6.2-FRkEyCRDCMJ4V7FViKOnGY=a5f6b4f0b968fa7b1bee7784729ec9b2
             transformers-0.5.2.0=b5dee110a615d751493b7ce1c6f95946
             vector-0.12.0.1-JlawpRjIcMJIYPJVsWriIA=137c9db50bf637e10c6e6dd9e685ce59
             primitive-0.6.3.0-CXy1O9sQYlI58rn9KQkFyo=b4457a9f891c4eea587ee58a79b7f0fc
             deepseq-1.4.3.0=e843b5d736cc095915bf2399fddf152e
             containers-0.5.10.2=0f9db0d1b935cacba444aac19f4cb54d
haddock-interfaces: /usr/share/doc/haskell-juicypixels/html/JuicyPixels.haddock
haddock-html: /usr/share/doc/haskell-juicypixels/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-juicypixels-3.2.9.5-1-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-juicypixels.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: JuicyPixels
version: 3.2.9.5
id: JuicyPixels-3.2.9.5-ASGnSU2nyj8KgOo9KfthVh
key: JuicyPixels-3.2.9.5-ASGnSU2nyj8KgOo9KfthVh
license: BSD3
maintainer: vincent.berthoux@gmail.com
stability: Stable
homepage: https://github.com/Twinside/Juicy.Pixels
synopsis: Picture loading/serialization (in png, jpeg, bitmap, gif, tga, tiff and radiance)
description:
    <<data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAAMAAAADABAMAAACg8nE0AAAAElBMVEUAAABJqDSTWEL/qyb///8AAABH/1GTAAAAAXRSTlMAQObYZgAAAN5JREFUeF7s1sEJgFAQxFBbsAV72v5bEVYWPwT/XDxmCsi7zvHXavYREBDI3XP2GgICqBBYuwIC+/rVayPUAyAg0HvIXBcQoDFDGnUBgWQQ2Bx3AYFaRoBpAQHWb3bt2ARgGAiCYFFuwf3X5HA/McgGJWI2FdykCv4aBYzmKwDwvl6NVmUAAK2vlwEALK7fo88GANB6HQsAAAAAAAAA7P94AQCzswEAAAAAAAAAAAAAAAAAAICzh4UAO4zWAYBfRutHA4Bn5C69JhowAMGoBaMWDG0wCkbBKBgFo2AUAACPmegUST/IJAAAAABJRU5ErkJggg==>>
    .
    This library can load and store images in PNG,Bitmap, Jpeg, Radiance, Tiff and Gif images.
category: Codec, Graphics, Image
author: Vincent Berthoux
exposed: True
indefinite: False
exposed-modules:
    Codec.Picture Codec.Picture.Bitmap Codec.Picture.ColorQuant
    Codec.Picture.Gif Codec.Picture.HDR Codec.Picture.Jpg
    Codec.Picture.Metadata Codec.Picture.Metadata.Exif
    Codec.Picture.Png Codec.Picture.Saving Codec.Picture.Tga
    Codec.Picture.Tiff Codec.Picture.Types
hidden-modules: Codec.Picture.Jpg.DefaultTable
                Codec.Picture.Jpg.Metadata Codec.Picture.Jpg.FastIdct
                Codec.Picture.Jpg.FastDct Codec.Picture.Jpg.Types
                Codec.Picture.Jpg.Common Codec.Picture.Jpg.Progressive
                Codec.Picture.Gif.LZW Codec.Picture.Gif.LZWEncoding
                Codec.Picture.Png.Export Codec.Picture.Png.Type
                Codec.Picture.Png.Metadata Codec.Picture.Tiff.Metadata
                Codec.Picture.Tiff.Types Codec.Picture.BitWriter
                Codec.Picture.InternalHelper Codec.Picture.VectorByteConversion
abi: f684dd48218258b0799e18e42331ec77
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/JuicyPixels-3.2.9.5
library-dirs: /usr/lib/ghc-8.2.2/site-local/JuicyPixels-3.2.9.5
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.2.2/JuicyPixels-3.2.9.5
hs-libraries: HSJuicyPixels-3.2.9.5-ASGnSU2nyj8KgOo9KfthVh
include-dirs: /usr/lib/ghc-8.2.2/site-local/JuicyPixels-3.2.9.5/include
depends:
    base-4.10.1.0 bytestring-0.10.8.2 mtl-2.2.2-8XubxMJDT8QLsstvlNotkc
    binary-0.8.5.1 zlib-0.6.2-FRkEyCRDCMJ4V7FViKOnGY
    transformers-0.5.2.0 vector-0.12.0.1-JlawpRjIcMJIYPJVsWriIA
    primitive-0.6.3.0-CXy1O9sQYlI58rn9KQkFyo deepseq-1.4.3.0
    containers-0.5.10.2
abi-depends: base-4.10.1.0=0ea45191c57c268b2351cb731ab6a0d6
             bytestring-0.10.8.2=4b2726b654ceeff6535e698a2a1e724e
             mtl-2.2.2-8XubxMJDT8QLsstvlNotkc=9d788b97813db77c2d48570ade6e04a9
             binary-0.8.5.1=33c677d3ced9a5afbc7b354509494653
             zlib-0.6.2-FRkEyCRDCMJ4V7FViKOnGY=a5f6b4f0b968fa7b1bee7784729ec9b2
             transformers-0.5.2.0=b5dee110a615d751493b7ce1c6f95946
             vector-0.12.0.1-JlawpRjIcMJIYPJVsWriIA=137c9db50bf637e10c6e6dd9e685ce59
             primitive-0.6.3.0-CXy1O9sQYlI58rn9KQkFyo=b4457a9f891c4eea587ee58a79b7f0fc
             deepseq-1.4.3.0=e843b5d736cc095915bf2399fddf152e
             containers-0.5.10.2=0f9db0d1b935cacba444aac19f4cb54d
haddock-interfaces: /usr/share/doc/haskell-juicypixels/html/JuicyPixels.haddock
haddock-html: /usr/share/doc/haskell-juicypixels/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
